use std::fs::File;
use std::io::SeekFrom;
use std::io::prelude::*;
use super::Sensor;

pub struct BatterySensor {
    charge_now: File,
    charge_full: File
}

impl BatterySensor {
    pub fn new(supply: &str) -> BatterySensor {
        let path = format!("/sys/class/power_supply/{}", supply);
        BatterySensor {
            charge_now: File::open(format!("{}/{}", path, "charge_now")).unwrap(),
            charge_full: File::open(format!("{}/{}", path, "charge_full")).unwrap()
        }
    }
}

impl Sensor for BatterySensor {
    fn status(&mut self) -> String {
        let mut s = String::new();

        self.charge_now.read_to_string(&mut s).ok().expect("Could not read current charge");
        let charge_now : u32 = s.trim().parse().ok().expect("Could not parse charge");

        s.clear();

        self.charge_full.read_to_string(&mut s).ok().expect("Could not read current charge");
        let charge_full : u32 = s.trim().parse().ok().expect("Could not parse charge");

        self.charge_now.seek(SeekFrom::Start(0)).ok();
        self.charge_full.seek(SeekFrom::Start(0)).ok();

        format!("{}%", charge_now / (charge_full / 100))
    }
}

