use std::fs::File;
use std::io::SeekFrom;
use std::io::prelude::*;
use super::Sensor;

pub struct TempSensor {
    file: File
}

impl TempSensor {
    pub fn new(zone: &str) -> TempSensor {
        let path = format!("/sys/class/thermal/{}/temp", zone);
        TempSensor {
            file: File::open(path).unwrap()
        }
    }
}

impl Sensor for TempSensor {
    fn status(&mut self) -> String {
        let mut s = String::new();
        self.file.read_to_string(&mut s).ok().expect("Could not read temperature stats");
        let i : Option<u32> = s.trim().parse().ok();
        self.file.seek(SeekFrom::Start(0)).ok().expect("Could not reread temperature");

        match i {
            Some(i) => format!("{}°C", i/1000),
            None => "?°C".to_string(),
        }
    }
}


